/*
 * =======================================================================
 * ============================ WIZARD BEAN ==============================
 * =======================================================================
 *
 *                                                 Copyright (C) 2002 Chir
 *
 * DESCRIPTION:   This Swing bean contains a wizard framework,
 *                to make it easier to create wizards.
 *
 * THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
 * THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
 * (AT YOUR OPTION) ANY LATER VERSION.
 *
 * THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  SEE THE
 * GNU GENERAL PUBLIC LICENSE FOR MORE DETAILS.
 *
 * YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
 * ALONG WITH THIS PROGRAM; IF NOT, WRITE TO THE FREE SOFTWARE
 * FOUNDATION, INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
 */
 
package org.chir.swing;

import java.awt.*;
import java.io.Serializable;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.beans.*;

/**
 * Bean wrapper for the WizardComponent class.
 */
public class Wizard extends WizardComponent /*implements Serializable*/      // Visual Bean.
{
    private PropertyChangeSupport changes = new PropertyChangeSupport(this);
    private VetoableChangeSupport vetos = new VetoableChangeSupport(this);

    public Wizard()
    {
        setSize( 500, 250 );
    }

    public void setBackText( String s ) // override base class' definition.
    {
        String temp = getBackText();
        super.setBackText( s );
        changes.firePropertyChange( "BackText", temp, s );
    }
    public void setNextText( String s ) // override base class' definition.
    {
        String temp = getNextText();
        super.setNextText( s );
        changes.firePropertyChange( "NextText", temp, s );
    }

/*
    // Needed for Beans.
    public Dimension getMinimumSize()
    {
        return new Dimension( 500, 250 );
    }
    public void setMinimumSize(Dimension d)
    {
    }
    public void setMinimumSize(int w, int h)
    {
    }
*/
    //----------------------------------------------------------------------
    // Methods for registering listeners:

    /**
     * The specified PropertyChangeListeners <b>propertyChange</b> method will
     * be called each time the value of any bound property is changed.
     * The PropertyListener object is addded to a list of PropertyChangeListeners
     * managed by the Bean, it can be removed with removePropertyChangeListener.
     * Note: the JavaBeans specification does not require PropertyChangeListeners
     * to run in any particular order.
     *
     * @see #removePropertyChangeListener
     * @param l the PropertyChangeListener
     */      
    public void addPropertyChangeListener(PropertyChangeListener l)
    {
    	changes.addPropertyChangeListener(l);
    }

    /** 
     * Remove this PropertyChangeListener from the JellyBeans internal list.  
     * If the PropertyChangeListener isn't on the list, silently do nothing.
     * 
     * @see #addPropertyChangeListener
     * @param l the PropertyChangeListener
     */      
    public void removePropertyChangeListener(PropertyChangeListener l)
    {
    	changes.removePropertyChangeListener(l);
    }

    /**
     * The specified VetoableChangeListeners <b>vetoableChange</b> method will
     * be called each time the value of any constrained property is changed.
     * Currently, the only constrained property is "priceInCents".
     * The VetoableChangeListener object is addded to a list of VetoableChangeListeners
     * managed by the Bean, it can be removed with removeVetoableChangeListener.
     * Note: the JavaBeans specification does not require VetoableChangeListeners
     * to run in any particular order.
     *
     * @see #removeVetoableChangeListener
     * @param l the VetoableChangeListener
     */      
    public void addVetoableChangeListener(VetoableChangeListener l)
    {
    	vetos.addVetoableChangeListener(l);
    }

    /** 
     * Remove this VetoableChangeListener from the Beans internal list.  
     * If the VetoableChangeListener isn't on the list, silently do nothing.
     * 
     * @see #addVetoableChangeListener
     * @param l the VetoableChangeListener
     */      
    public void removeVetoableChangeListener(VetoableChangeListener l)
    {
    	vetos.removeVetoableChangeListener(l);
    }
}
// ----------------------------------------
