/*
 * =======================================================================
 * ============================ WIZARD BEAN ==============================
 * =======================================================================
 *
 *                                                 Copyright (C) 2002 Chir
 *
 * DESCRIPTION:   This Swing bean contains a wizard framework,
 *                to make it easier to create wizards.
 *
 * THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 * IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
 * THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
 * (AT YOUR OPTION) ANY LATER VERSION.
 *
 * THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  SEE THE
 * GNU GENERAL PUBLIC LICENSE FOR MORE DETAILS.
 *
 * YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
 * ALONG WITH THIS PROGRAM; IF NOT, WRITE TO THE FREE SOFTWARE
 * FOUNDATION, INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
 */

package org.chir.swing;

import java.io.*;
import java.awt.*;
import javax.swing.*;
import java.net.*;
import java.util.*;

/**
 * Base class for wizard panels.<br>
 * To be derived to implement each wizard's page.<br>
 * Instances of WizardPanel have to be added to a WizardComponent in order to be used.
 *
 * @author  Chir
 */
public /*abstract*/ class WizardPanel extends JPanel
{
    /** @param p    The component to add to this wizard page.
     */
    public WizardPanel( Component p )
    {
        setMinimumSize( new Dimension(500, 278) );
        setPreferredSize( new Dimension(500, 278) );
        setLayout( new BorderLayout() );
        if( p != null )  add( p, BorderLayout.CENTER );
    }
    public WizardPanel()
    {
    	this( null );
    }
    
    /** Determines if the Next button must be disabled, to prevent going on while some conditions are not fulfilled. */
    public boolean canMoveNext()
    {
        return true;
    }

    /** Determines if the Back button must appear. */
    public boolean canMoveBack()
    {
        return true;
    }
    
    /** Actually moves to the next step.
     * @return  True if the move succeeded.
     */
    public boolean moveNext()
    {
        return true;
    }

    /** Actually moves to the previous step.
     * @return  True if the move succeeded.
     */
    public boolean moveBack()
    {
        return true;
    }

    /** Prepares the panel to be shown. */
    public void showPanel()
    {
        /* Do nothing */
    }
    public WizardComponent getWizard()  { return m_parent; }
    protected void setParent( WizardComponent p )  { m_parent = p; }
    
    private WizardComponent m_parent;   // The wizard this panel was added to.
}